@@ -287,6 +287,7 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
     ProcessAlarm()
 
     if(data.DisplayIsOn==True):
+        RecordWindow.UpdateAnimation() #show turning clock
         if(data.debug==1): print "-> o Update screen"
         RecordWindow.UpdateScreen()
     else:
@@ -316,6 +317,7 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
 
 
 
+
 ###########################################################################
 ## Start the measurement
 ###########################################################################
@@ -323,6 +325,10 @@ def InitMeasurement():
     global app
 
     data.sample_index=0
+
+    data.Animation=7
+    RecordWindow.UpdateAnimation() #show turning clock
+
     if(data.QuickMode==False): data.Status=_("Recording...")
     else: data.Status=_("Recording in Test Mode...")
 
@@ -513,7 +519,10 @@ def About(ui):
     _("Version:")+" "+str(data.version)+"-"+str(data.build)+"\n"+\
     _("Contact:")+" george@ruinelli.ch\n" +\
     _("Website:")+" http://www.ruinelli.ch/sleepanalyser/\n\n"+\
-    _("Feedback and donations are very welcome!"))
+    _("Feedback and donations are very welcome!")+"\n\n"+\
+    _("Translations:")+\
+    "\nEnglish, Deutsch: George Ruinelli\n"+\
+    "Francais: ??")
 
 
 
@@ -777,6 +786,7 @@ class frmRecordWindow(QMainWindow):
             self.ui.bRaiseTrigger.setIcon(QIcon(data.app_path+"img/"+"go-up.png"))
             self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"img/"+"go-down.png"))
             self.ui.bEditNote.setIcon(QIcon(data.app_path+"img/"+"kwrite.png"))
+            self.ui.lblAnimation.setPixmap(QtGui.QPixmap(data.app_path+"img/anim/0.png"))
 
         self.setWindowTitle("SleepAnalyser ("+_("Recording")+")")
         self.ui.lblElapsedTime.setText(_("Elapsed time:")+" 0")
@@ -855,6 +865,12 @@ class frmRecordWindow(QMainWindow):
 
 
 
+    def UpdateAnimation(self):
+        data.Animation=(data.Animation+1) % 8
+        self.ui.lblAnimation.setPixmap(QtGui.QPixmap(data.app_path+"img/anim/"+str(data.Animation)+".png"))
+#        print data.Animation
+
+
     def StopMeasurement(self): ##(Class RecordWindow)
             self.closeEvent(0)
 
@@ -1117,9 +1133,10 @@ class frmViewWindow(QMainWindow):
 #            QtGui.QMessageBox.warning(self, 'File version too old!', "Can not load record \n"+data.logfilename+"\nas it got created from SleepAnalyser version <1.6 and is not compatible with the current SleepAnalyser version.", QtGui.QMessageBox.Ok)
 #        LoadFileList()
 
-
-        self.UpdateScreen()
-        app.processEvents() #force ui update
+        if(data.demo==False): #We are on a N900
+            #It gives miss behavior on PC, so only do on N900
+            self.UpdateScreen()
+            app.processEvents() #force ui update
 
 
         self.ui.lblStatus.setText(_("Processessing data..."))
